# Disclaimer

FillingPatterns package coded by G. Iadarola, A. Poyet, G. Sterbini, available at https://github.com/PyCOMPLETE/FillingPatterns/tree/master
The package was manually added as it's not pip installable.
